# Makefile for IEEE Customization
# 
# build with Saxon and fop
#
# Variables that are likely to need to be modified:
#
# Replace with path to your personal resolver directory 
RESOLVERDIR = $(HOME)/.resolver
# Replace with path to saxon.jar and xml-commons-resolver.jar
SAXONJAR    = /usr/share/saxon/saxon.jar
RESOLVERJAR = /usr/share/java/xml-commons-resolver.jar
# Version of DocBook Transforms
DBXSLVER = 1.76.1
# Replace with path to DocBook Transforms
DBTRANSFORMS =  /usr/share/xml/docbook/stylesheet/nwalsh/$(DBXSLVER)
SAXONEXTJAR = $(DBTRANSFORMS)/extensions/saxon653.jar
#
# CLASSPATH and java call
#
CP = $(RESOLVERDIR):$(RESOLVERJAR):$(SAXONJAR):$(SAXONEXTJAR)
JAVA = java -classpath $(CP)
#
# Source and output directories and files
#
graphicsdir = graphics
pdfdir      = pdf
PDFTARGET   = authguide.pdf

# Customization file
fostyle = fo.xsl

# saxon arguments
resolverargx = -x org.apache.xml.resolver.tools.ResolvingXMLReader
resolverargy = -y org.apache.xml.resolver.tools.ResolvingXMLReader
resolverargr = -r org.apache.xml.resolver.tools.CatalogResolver
resolverargs = $(resolverargx) $(resolverargy) $(resolverargr) 
SAXON = $(JAVA) com.icl.saxon.StyleSheet

# Fop call
FOP = fop

all: $(PDFTARGET)

pdf: $(PDFTARGET)

%.fo: %.xml
	$(SAXON) $(resolverargs) -u -o $@ $< $(fostyle)

%.pdf: %.fo
	@if test ! -d $(pdfdir) ; then mkdir $(pdfdir);  fi;
	$(FOP) -fo $< -pdf $(pdfdir)/$@

clean:
	rm -f *.fo $(pdfdir)/*.pdf *~

clobber: clean
	rmdir -f $(pdfdir)
